@@ -26,7 +26,7 @@ output = ""
 exchange = None
 container_files_path = None
 
-container_version = "3"
+container_version = "4"
 
 
 def deal_with_stdout():
@@ -47,12 +47,16 @@ def import_all_c2_functions():
     # Get file paths of all modules.
     modules = glob.glob("c2_functions/*.py")
     invalidate_caches()
-    for x in modules:
-        if not x.endswith("__init__.py") and x[-3:] == ".py":
-            module = import_module("c2_functions." + pathlib.Path(x).stem, package=None)
-            for el in dir(module):
-                if "__" not in el:
-                    globals()[el] = getattr(module, el)
+    try:
+        for x in modules:
+            if not x.endswith("__init__.py") and x[-3:] == ".py":
+                module = import_module("c2_functions." + pathlib.Path(x).stem, package=None)
+                for el in dir(module):
+                    if "__" not in el:
+                        globals()[el] = getattr(module, el)
+    except Exception as e:
+        print_flush("[-] Failed to parse c2_functions code:\n" + str(e))
+        sys.exit(1)
 
 
 async def send_status(message="", routing_key=""):
@@ -334,7 +338,7 @@ async def connect_and_consume_rpc(debug):
     while connection is None:
         try:
             if debug:
-                print_flush("Connecting to rabbitmq in connect_and_consume_rpc")
+                print_flush(f"Connecting to rabbitmq in connect_and_consume_rpc with c2 {hostname}")
             connection = await aio_pika.connect_robust(
                 host=settings.get("host", "127.0.0.1"),
                 login=settings.get("username", "mythic_user"),
@@ -342,7 +346,7 @@ async def connect_and_consume_rpc(debug):
                 virtualhost=settings.get("virtual_host", "mythic_vhost"),
             )
             if debug:
-                print_flush("Successfully connected in connect_and_consume_rpc")
+                print_flush(f"Successfully connected in connect_and_consume_rpc with c2 {hostname}")
         except (ConnectionError, ConnectionRefusedError) as c:
             print_flush("Connection to rabbitmq failed, trying again...")
         except Exception as e:
@@ -353,10 +357,12 @@ async def connect_and_consume_rpc(debug):
     if debug:
         print_flush("Declaring container specific rpc queue in connect_and_consume_rpc")
     queue = await channel.declare_queue("{}_rpc_queue".format(hostname), auto_delete=True)
+    if debug:
+            print_flush("Successfully declared container specific rpc queue in connect_and_consume_rpc with c2 {hostname}")
     await channel.set_qos(prefetch_count=10)
     try:
         if debug:
-            print_flush("Starting to consume callbacks in connect_and_consume_rpc")
+            print_flush("Starting to consume callbacks in connect_and_consume_rpc with c2 {hostname}")
         await queue.consume(
             partial(rabbit_c2_rpc_callback, channel.default_exchange)
         )
@@ -393,7 +399,7 @@ async def connect_and_consume_mythic_rpc(debug):
     while connection is None:
         try:
             if debug:
-                print_flush("Connecting to rabbitmq in connect_and_consume_mythic_rpc")
+                print_flush(f"Connecting to rabbitmq in connect_and_consume_mythic_rpc with c2 {hostname}")
             connection = await aio_pika.connect_robust(
                 host=settings.get("host", "127.0.0.1"),
                 login=settings.get("username", "mythic_user"),
@@ -401,7 +407,7 @@ async def connect_and_consume_mythic_rpc(debug):
                 virtualhost=settings.get("virtual_host", "mythic_vhost"),
             )
             if debug:
-                print_flush("Successfully connected in connect_and_consume_mythic_rpc")
+                print_flush(f"Successfully connected in connect_and_consume_mythic_rpc with c2 {hostname}")
         except (ConnectionError, ConnectionRefusedError) as c:
             print_flush("Connection to rabbitmq failed, trying again...")
         except Exception as e:
@@ -410,7 +416,7 @@ async def connect_and_consume_mythic_rpc(debug):
     channel = await connection.channel()
     # get a random queue that only the apfell server will use to listen on to catch all heartbeats
     if debug:
-        print_flush("Declaring container specific mythic rpc queue in connect_and_consume_mythic_rpc")
+        print_flush(f"Declaring container specific mythic rpc queue in connect_and_consume_mythic_rpc with c2 {hostname}")
     queue = await channel.declare_queue("{}_mythic_rpc_queue".format(hostname), auto_delete=True)
     await channel.set_qos(prefetch_count=10)
     try:
@@ -431,11 +437,16 @@ async def mythic_service(debug: bool):
     global container_files_path
     connection = None
     hostname = settings.get("name", "hostname")
+    
     if hostname == "hostname":
         hostname = socket.gethostname()
+    if debug:
+        print_flush(f"Setting c2 name to {hostname}")
     container_files_path = pathlib.Path(
         os.path.abspath(settings.get("container_files_path", "/Mythic/"))
     )
+    if debug:
+        print_flush(f"Setting the absolute path to the c2's mythic folder as: {container_files_path}")
     container_files_path = container_files_path / "c2_code"
     while connection is None:
         try:
